# Carbon Arc - Python Package

Client for [Carbon Arc](https://carbonarc.co/), an Insights Exchange Platform.

## Usage

**Installation**

```bash
pip install carbonarc
```

**Quick Start**

Initialize the API client with authentication.

```python
from carbonarc import CarbonArcClient

client = CarbonArcClient(token="<token>") # retrieve token from account
```

## Resources

- [Tutorials](https://github.com/Carbon-Arc/carbonarc-tutorials)
- [Docs](https://docs.carbonarc.co/)
- [App](https://app.carbonarc.co/)
- [API](https://api.carbonarc.co/)